@@ -1,6 +1,6 @@
 ;;; parser-generator-lex-analyzer.el --- Lex-analyzer library -*- lexical-binding: t -*-
 
-;; Copyright (C) 2020-2024  Free Software Foundation, Inc.
+;; Copyright (C) 2020-2025  Free Software Foundation, Inc.
 
 
 ;;; Commentary:
@@ -18,13 +18,23 @@
 (defvar
   parser-generator-lex-analyzer--get-function
   nil
-  "Get token contents.  Anything other than nil is expected.")
+  "Get token contents.  Any return is valid even nil.")
+
+(defvar
+  parser-generator-lex-analyzer--get-function-export-string
+  ""
+  "String version of get function, used only when generating exports. This is needed because Emacs compilation obfuscates lambda source code after so it is not printable anymore. Easiest way to populate this is to copy the lambda source code into a string and manually escape double quotes.")
 
 (defvar
   parser-generator-lex-analyzer--function
   nil
   "Get next token like \='(a b . c) or nil, expects signal if input-tape is invalid.")
 
+(defvar
+  parser-generator-lex-analyzer--function-export-string
+  ""
+  "String version of get function, used only when generating exports. This is needed because Emacs compilation obfuscates lambda source code after so it is not printable anymore. Easiest way to populate this is to copy the lambda source code into a string and manually escape double quotes.")
+
 (defvar
   parser-generator-lex-analyzer--state-init
   nil
@@ -89,12 +99,6 @@
           (car (cdr error)))
          token
          (car (cdr error))))))
-    (unless meta-information
-      (signal
-       'error
-       (list
-        (format "Could not find any token meta-information for: %s" token)
-        token)))
     meta-information))
 
 (defun parser-generator-lex-analyzer--peek-next-look-ahead ()
