@@ -1,6 +1,6 @@
 ;;; parser-generator-lr-export-test.el --- Tests for LR(k) Parser Export -*- lexical-binding: t -*-
 
-;; Copyright (C) 2020-2024  Free Software Foundation, Inc.
+;; Copyright (C) 2020-2025  Free Software Foundation, Inc.
 
 
 ;;; Commentary:
@@ -45,7 +45,6 @@
                  (end (+ index 1)))
              (let ((token (buffer-substring-no-properties start end)))
                (list `(,token ,start . ,end) nil end nil)))))))
-
     (setq
      parser-generator-lex-analyzer--get-function
      (lambda (token)
@@ -64,6 +63,24 @@
       "bbaa"
       (parser-generator-lr-translate)))
 
+    (setq
+     parser-generator-lex-analyzer--function-export-string
+     "(lambda (index _state)
+       (with-current-buffer \"*a*\"
+         (when (<= (+ index 1) (point-max))
+           (let ((start index)
+                 (end (+ index 1)))
+             (let ((token (buffer-substring-no-properties start end)))
+               (list `(,token ,start . ,end) nil end nil))))))")
+    (setq
+     parser-generator-lex-analyzer--get-function-export-string
+     "(lambda (token)
+       (with-current-buffer \"*a*\"
+         (let ((start (car (cdr token)))
+               (end (cdr (cdr token))))
+           (when (<= end (point-max))
+             (buffer-substring-no-properties start end)))))")
+
     ;; Export parser
     (let ((export (parser-generator-lr-export-to-elisp "ba")))
       (parser-generator--debug
@@ -179,11 +196,28 @@
          (push (nth (1- index) string) tokens)
          (setq index (1+ index)))
        (list (nreverse tokens) nil index nil))))
+  (setq
+   parser-generator-lex-analyzer--function-export-string
+   "(lambda (index _state)
+     (let* ((string '((a 1 . 2) (a 2 . 3) (b 3 . 4) (b 4 . 5)))
+            (string-length (length string))
+            (max-index index)
+            (tokens))
+       (while (and
+               (< (1- index) string-length)
+               (< (1- index) max-index))
+         (push (nth (1- index) string) tokens)
+         (setq index (1+ index)))
+       (list (nreverse tokens) nil index nil)))")
 
   (setq
    parser-generator-lex-analyzer--get-function
    (lambda (token)
      (car token)))
+  (setq
+   parser-generator-lex-analyzer--get-function-export-string
+   "(lambda (token)
+     (car token))")
 
   ;; Test parse
   (should
@@ -194,8 +228,7 @@
 
   ;; Export parser
   (let ((export (parser-generator-lr-export-to-elisp "e")))
-    (parser-generator--debug
-     (message "export:\n%S\n" export))
+     (message "export:\n%S\n" export)
 
     (with-temp-buffer
       (insert export)
@@ -240,6 +273,15 @@
                  (end (+ index 1)))
              (let ((token (buffer-substring-no-properties start end)))
                (list `(,token ,start . ,end) nil end nil)))))))
+    (setq
+     parser-generator-lex-analyzer--function-export-string
+     "(lambda (index _state)
+       (with-current-buffer \"*a*\"
+         (when (<= (+ index 1) (point-max))
+           (let ((start index)
+                 (end (+ index 1)))
+             (let ((token (buffer-substring-no-properties start end)))
+               (list `(,token ,start . ,end) nil end nil))))))")
 
     (setq
      parser-generator-lex-analyzer--get-function
@@ -249,6 +291,14 @@
                (end (cdr (cdr token))))
            (when (<= end (point-max))
              (buffer-substring-no-properties start end))))))
+    (setq
+     parser-generator-lex-analyzer--get-function-export-string
+     "(lambda (token)
+       (with-current-buffer \"*a*\"
+         (let ((start (car (cdr token)))
+               (end (cdr (cdr token))))
+           (when (<= end (point-max))
+             (buffer-substring-no-properties start end)))))")
 
     (should
      (equal
@@ -312,6 +362,15 @@
                (end (+ index 1)))
            (let ((token (buffer-substring-no-properties start end)))
              (list `(,token ,start . ,end) nil end nil)))))))
+  (setq
+   parser-generator-lex-analyzer--function-export-string
+   "(lambda (index _state)
+     (with-current-buffer \"*a*\"
+       (when (<= (+ index 1) (point-max))
+         (let ((start index)
+               (end (+ index 1)))
+           (let ((token (buffer-substring-no-properties start end)))
+             (list `(,token ,start . ,end) nil end nil))))))")
 
   (setq
    parser-generator-lex-analyzer--get-function
@@ -323,6 +382,16 @@
            (buffer-substring-no-properties
             start
             end))))))
+  (setq
+   parser-generator-lex-analyzer--get-function-export-string
+   "(lambda (token)
+     (with-current-buffer \"*a*\"
+       (let ((start (car (cdr token)))
+             (end (cdr (cdr token))))
+         (when (<= end (point-max))
+           (buffer-substring-no-properties
+            start
+            end)))))")
 
   (should
    (equal
@@ -384,7 +453,6 @@
                  (end (+ index 1)))
              (let ((token (buffer-substring-no-properties start end)))
                (list `(,token ,start . ,end) nil end nil)))))))
-
     (setq
      parser-generator-lex-analyzer--get-function
      (lambda (token)
@@ -401,6 +469,24 @@
 
     (message "Passed translate before export")
 
+    (setq
+     parser-generator-lex-analyzer--function-export-string
+     "(lambda (index _state)
+       (with-current-buffer \"*a*\"
+         (when (<= (+ index 1) (point-max))
+           (let ((start index)
+                 (end (+ index 1)))
+             (let ((token (buffer-substring-no-properties start end)))
+               (list `(,token ,start . ,end) nil end nil))))))")
+    (setq
+     parser-generator-lex-analyzer--get-function-export-string
+     "(lambda (token)
+       (with-current-buffer \"*a*\"
+         (let ((start (car (cdr token)))
+               (end (cdr (cdr token))))
+           (when (<= end (point-max))
+             (buffer-substring-no-properties start end)))))")
+
     ;; Export parser
     (let ((export (parser-generator-lr-export-to-elisp "fa")))
       (with-temp-buffer
